@@ -104,7 +104,7 @@ static GtkActionEntry entries[] = {
 	 G_CALLBACK (brasero_video_disc_edit_information_cb)},
 	{"DeleteVideo", GTK_STOCK_REMOVE, NULL, NULL, N_("Remove the selected videos from the project"),
 	 G_CALLBACK (brasero_video_disc_delete_activated_cb)},
-	{"PasteVideo", GTK_STOCK_PASTE, NULL, NULL, N_("Add the files stored in the clipboard"),
+	{"PasteVideo", NULL, N_("Paste files"), NULL, N_("Add the files stored in the clipboard"),
 	 G_CALLBACK (brasero_video_disc_paste_activated_cb)},
 /*	{"Split", "transform-crop-and-resize", N_("_Split Track…"), NULL, N_("Split the selected track"),
 	 G_CALLBACK (brasero_video_disc_split_cb)} */
@@ -429,7 +429,7 @@ brasero_video_disc_session_changed (BraseroSessionCfg *session,
 
 	priv = BRASERO_VIDEO_DISC_PRIVATE (self);
 
-	if (!GTK_WIDGET (self)->window)
+	if (!gtk_widget_get_window (GTK_WIDGET (self)))
 		return;
 
 	/* make sure all tracks have video */
@@ -480,7 +480,7 @@ brasero_video_disc_session_changed (BraseroSessionCfg *session,
 			continue;
 		}
 
-		if (result == BRASERO_BURN_NOT_READY) {
+		if (result == BRASERO_BURN_NOT_READY || result == BRASERO_BURN_RUNNING) {
 			notready = TRUE;
 			continue;
 		}
